@@ -1,10 +1,11 @@
 /*
-Copyright 2012  Evan Teran evan.teran@gmail.com
+Copyright (C) 2001 - 2013 Evan Teran
+                          evan.teran@gmail.com
 
-This program is free software; you can redistribute it and/or
-modify it under the terms of the GNU General Public License as
-published by the Free Software Foundation; either version 2 of 
-the License, or (at your option) any later version.
+This program is free software: you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation, either version 2 of the License, or
+(at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
